@@ -166,7 +166,7 @@ public class VetoableASTTransformation extends BindableASTTransformation {
     /**
      * Wrap an existing setter.
      */
-    private void wrapSetterMethod(ClassNode classNode, boolean bindable, String propertyName) {
+    private static void wrapSetterMethod(ClassNode classNode, boolean bindable, String propertyName) {
         String getterName = "get" + MetaClassHelper.capitalize(propertyName);
         MethodNode setter = classNode.getSetterMethod("set" + MetaClassHelper.capitalize(propertyName));
 
