@@ -64,7 +64,6 @@ public class CompilerConfigurationTest extends GroovyTestCase {
             assertNotNull(listCP);
             assertEquals(0, listCP.size());
         }
-        assertNotNull(config.getOutput());
         assertNull(config.getTargetDirectory());
         assertEquals(".groovy", config.getDefaultScriptExtension());
         assertNull(config.getJointCompilationOptions());
@@ -102,7 +101,6 @@ public class CompilerConfigurationTest extends GroovyTestCase {
             assertNotNull(listCP);
             assertEquals(0, listCP.size());
         }
-        assertNotNull(config.getOutput());
         assertNull(config.getTargetDirectory());
         assertEquals(".groovy", config.getDefaultScriptExtension());
         assertNull(config.getJointCompilationOptions());
@@ -123,9 +121,6 @@ public class CompilerConfigurationTest extends GroovyTestCase {
         init.setRecompileGroovySource(true);
         init.setClasspath("File1" + File.pathSeparator + "Somewhere");
 
-        final PrintWriter initOut = new PrintWriter(System.out);
-        init.setOutput(initOut);
-
         final File initTDFile = new File("A wandering path");
         init.setTargetDirectory(initTDFile);
         init.setDefaultScriptExtension(".jpp");
@@ -151,7 +146,6 @@ public class CompilerConfigurationTest extends GroovyTestCase {
             assertEquals("File1", listCP.get(0));
             assertEquals("Somewhere", listCP.get(1));
         }
-        assertEquals(initOut, init.getOutput());
         assertEquals(initTDFile, init.getTargetDirectory());
         assertEquals(".jpp", init.getDefaultScriptExtension());
         assertEquals(initJoint, init.getJointCompilationOptions());
@@ -173,7 +167,6 @@ public class CompilerConfigurationTest extends GroovyTestCase {
             assertEquals("File1", listCP.get(0));
             assertEquals("Somewhere", listCP.get(1));
         }
-        assertEquals(initOut, config.getOutput());
         assertEquals(initTDFile, config.getTargetDirectory());
         assertEquals(".jpp", config.getDefaultScriptExtension());
         assertEquals(initJoint, config.getJointCompilationOptions());
@@ -195,9 +188,6 @@ public class CompilerConfigurationTest extends GroovyTestCase {
         init.setRecompileGroovySource(false);
         init.setClasspath("");
 
-        final PrintWriter initOut = new PrintWriter(System.out);
-        init.setOutput(initOut);
-
         final File initTDFile = new File("A wandering path");
         init.setTargetDirectory(initTDFile);
 
@@ -215,7 +205,6 @@ public class CompilerConfigurationTest extends GroovyTestCase {
             assertNotNull(listCP);
             assertEquals(0, listCP.size());
         }
-        assertEquals(initOut, init.getOutput());
         assertEquals(initTDFile, init.getTargetDirectory());
 
         final CompilerConfiguration config = new CompilerConfiguration(init);
@@ -233,7 +222,6 @@ public class CompilerConfigurationTest extends GroovyTestCase {
             final List listCP = config.getClasspath();
             assertEquals(0, listCP.size());
         }
-        assertEquals(initOut, config.getOutput());
         assertEquals(initTDFile, config.getTargetDirectory());
     }
 }
\ No newline at end of file
